@@ -201,7 +201,12 @@ ErrCodeMsg SwReader::Read( const Reader& rOptions )
 
         mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
 
-        nError = po->Read( *mxDoc, msBaseURL, *pPam, maFileName );
+        {
+            // Performance mode: import all bookmarks names as defined in the document
+            auto perfModeGuard = mxDoc->getIDocumentMarkAccess()->disableUniqueNameChecks();
+
+            nError = po->Read(*mxDoc, msBaseURL, *pPam, maFileName);
+        }
 
         // an ODF document may contain redline mode in settings.xml; save it!
         ePostReadRedlineFlags = mxDoc->getIDocumentRedlineAccess().GetRedlineFlags();
@@ -341,6 +346,7 @@ ErrCodeMsg SwReader::Read( const Reader& rOptions )
 
     mxDoc->SetInReading( false );
     mxDoc->SetInXMLImport( false );
+    mxDoc->SetInXMLImport242(false);
     mxDoc->SetInWriterfilterImport(false);
 
     if (!mbSkipInvalidateNumRules)
